@@ -30,14 +30,14 @@ extern int verbose_mode;
 static char *
 get_code_str(FILE *f, iconv_t desc)
 {
-	unsigned char *icp, *ocp0, *ocp;
+	char *icp, *ocp0, *ocp;
 	size_t ibytes, obytes;
 	char *obuf;
 
-	unsigned char *utf8 = get_unicode_utf8(f);
+	char *utf8 = get_unicode_utf8(f);
 	if (utf8 == NULL || *utf8 == 0) {
-	/* fprintf(stderr, "get_code_str: NULL entry\n");*/
-	return NULL;
+		/* fprintf(stderr, "get_code_str: NULL entry\n");*/
+		return NULL;
 	}
 	#if 0 /* debug */
 	fprintf(stderr, "get_code_str: utf8: ");
@@ -50,12 +50,12 @@ get_code_str(FILE *f, iconv_t desc)
 	ibytes = strlen(utf8);
 	obuf = malloc(obytes);
 	if (obuf == NULL)
-	return NULL;
+		return NULL;
 	icp = utf8;
 	ocp0 = ocp = obuf + 1;
 	if (iconv(desc, &icp, &ibytes, &ocp, &obytes) == -1) {
-	/*        fprintf(stderr, "unrtf: my_iconv: iconv error\n");*/
-	return NULL;
+		/*        fprintf(stderr, "unrtf: my_iconv: iconv error\n");*/
+		return NULL;
 	}
 
 	// Set 1st byte to length
@@ -67,7 +67,6 @@ get_code_str(FILE *f, iconv_t desc)
 my_iconv_t
 my_iconv_open(const char *tocode, const char *fromcode)
 {
-	char *path = 0;
 	FILE *f;
 	my_iconv_t cd = MY_ICONV_T_CLEAR;
 	int c, i;
@@ -113,7 +112,6 @@ my_iconv(my_iconv_t cd, char **inbuf, size_t *inbytesleft, char **outbuf, size_t
 {
 	int c, i;
 	size_t result = 0;
-	char *obb = *outbuf;
 	**outbuf = 0;
 	if (cd.desc == (iconv_t) -1) {
 	if (cd.char_table != NULL)
